/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: meshmail.c
 * Author: Jed Marti
 * Description: Listen on a port, get a message, display it, write it to a file.
 * Created: Tue Dec  3 19:36:19 2024
 * Revision History:
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>

#include "meshmail.h"


// Port number to listen on. Set from the command line or default from meshmail.h. Note that this
// is not 1833 that Meshtastic MQTT expects. MQTT will know to send messages to this port if the
// mail address is an IPV4 number.
extern int32_t AREDNPortnum;

// How much noise to generate 0, none, 5 most.
extern uint8_t Noise;

int32_t main(int32_t argc, char *argv[])
{
  int32_t lastEMailNumber;

  //  Logo.
  printf("KI7NNP meshmail V%d.%02d.%03d\n", VERSION, RELEASE, PATCH);

  // Verify only one gateway.
  checkGateways();
  
  // Work over the command line to change defaults.
  cmdline(argc, argv);

  // Find the largest email number by scanning the mail directory for only numeric file names.
  // These will be the raw message files.
  lastEMailNumber = lastEmail();
  if (Noise > 2) printf("Last Email %d\n", lastEMailNumber);

  for (;;)
  {
    // Wait for contact.
    netListen(AREDNPortnum);

    // Copy message and write.
    copyAndSaveMessage(++lastEMailNumber);

    // Convert the message to HTML.
    convertToHTML(lastEMailNumber);

    // Rebuild the HTML index with 1 new message.
    buildindex(1);
  }
}


// EOF
