/* Copyright 2024 by COG9 Enterprises LLC
 * All rights reserved.
 * Title: message.c
 * Author: Jed Marti
 * Description: Read a message from the opened port and write it to a file.
 * Created: Wed Dec  4 08:33:38 2024
 * Revision History:
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>

#include "meshmail.h"


// File handle.
extern int32_t FD;

// Where messages go.
extern char *MailDir;

void copyAndSaveMessage(int32_t lemn)
/*     Read a message from the TCP connection and write it to the message directory in raw form.
 * Parameters:
 *   lemn: The message number.
 * External References:
 *   MAXPATHLEN: constant, how big can a file name get.
 *   MAXMSG: Maximum message size.
 *   FD: file handle for reading from TCP.
 * Returned values: none
 * Errors detected: Couldn't open the output file, couldn't read the message (lost connection
 *   most likely.
 */
{
  char    fname[MAXPATHLEN];
  FILE    *fh;
  ssize_t n, i;
  size_t  un;
  uint8_t msg[MAXMSG];

  // Create file name and open for writing.
  snprintf(fname, MAXPATHLEN, "%s/%d", MailDir, lemn);
  if ((fh = fopen(fname, "wb")) == NULL)
  {
    fprintf(stderr, "%s:%s:%d couldn't open %s because %s\n", __FILE__, __func__, __LINE__,
            fname, strerror(errno));
    exit(-1);
  }

  // Read packets until the sender closes the connection. This looks a little bogus.
  for (;;)
  {
    n = read(FD, msg, MAXMSG);
    if (n < 0)
    {
      fprintf(stderr, "%s:%s:%d Message read fails because %s\n", __FILE__, __func__, __LINE__,
              strerror(errno));
      close(FD);
      FD = -1;
      fclose(fh);
    }
    else if (n == 0)
    {
      close(FD);
      FD = -1;
      fclose(fh);
      return;
    }

    // Write the buffer to the file.
    un = fwrite(msg, (size_t) n, 1, fh);
  }
}


// EOF
